# Intentional - Textual TUI

[![Made for Intentional](https://img.shields.io/badge/made_for-intentional-blue)](https://intentional-ai.github.io/intentional/docs/home/)
[![PyPI - Version](https://img.shields.io/pypi/v/intentional-textual-ui.svg)](https://pypi.org/project/intentional-textual-ui)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-textual-ui.svg)](https://pypi.org/project/intentional-textual-ui)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)

Adds a Textual Terminal User Interface (TUI) for Intentional bots

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install intentional-textual-ui
```

## License

`intentional` is distributed under the terms of the [AGPL](LICENSE.txt) license. If that doesn't work for you, [get in touch](mailto:github@zansara.dev).
